RuntimeConfig

Enum RuntimeConfig 

pub enum RuntimeConfig {
    Local(LocalConfig),
    Remote(RemoteConfig),
}
The runtime configuration of the environment,

This configuration selects which runtime to use for this execution. The runtime is either local (i.e. parallelism is achieved only using threads), or remote (i.e. using both threads locally and remote workers).

In a remote execution the current binary is copied using scp to a remote host and then executed using ssh. The configuration of the remote environment should be specified via a YAML configuration file.

Local environment

let config = RuntimeConfig::local(1);
let env = StreamContext::new(config);

Remote environment

let config = r"
hosts:
  - address: host1
    base_port: 9500
    num_cores: 16
  - address: host2
    base_port: 9500
    num_cores: 24
";
let mut file = File::create("config.yaml").unwrap();
file.write_all(config.as_bytes());

let config = RuntimeConfig::remote("config.yaml").expect("cannot read config file");
let env = StreamContext::new(config);

From command line arguments

This reads from std::env::args() and reads the most common options (--local, --remote, --verbose). All the unparsed options will be returned into args. You can use --help to see their docs.

let (config, args) = RuntimeConfig::from_args();
let env = StreamContext::new(config);

Variants



Local(LocalConfig)

Use only local threads.



Remote(RemoteConfig)

Use both local threads and remote workers.

Implementations

Source

impl RuntimeConfig

pub fn from_args() -> (RuntimeConfig, Vec<String>)

Build the configuration from the specified args list.

pub fn local(num_cores: CoordUInt) -> RuntimeConfig

Local environment that avoid using the network and runs concurrently using only threads.

pub fn remote<P: AsRef<Path>>(config: P) -> Result<RuntimeConfig>

Remote environment based on the provided configuration file.

The behaviour of this changes if this process is the “runner” process (ie the one that will execute via ssh the other workers) or a worker process. If it’s the runner, the configuration file is read. If it’s a worker, the configuration is read directly from the environment variable and not from the file (remote hosts may not have the configuration file).

pub fn spawn_remote_workers(&self)

Spawn the remote workers via SSH and exit if this is the process that should spawn. If this is already a spawned process nothing is done.

pub fn host_id(&self) -> Option<CoordUInt>