Replication

Enum Replication 

pub enum Replication {
    Unlimited,
    Limited(CoordUInt),
    Host,
    One,
}
Replication factor for a block

Variants



Unlimited

The number of replicas is unlimited and will be determined by the launch configuration.



Limited(CoordUInt)

The number of replicas is limited to a fixed number.



Host

The number of replicas is limited to one per host.



One

The number of replicas is limited to one across all the hosts.

Implementations

Source

impl Replication

pub fn new_unlimited() -> Self

pub fn new_limited(size: CoordUInt) -> Self

pub fn new_host() -> Self

pub fn new_one() -> Self

pub fn is_unlimited(&self) -> bool

pub fn intersect(&self, rhs: Self) -> Self