IteratorSource

Struct IteratorSource 

pub struct IteratorSource<It>
where It: Iterator + Send + 'static, It::Item: Send,
{ /* private fields */ }
Source that consumes an iterator and emits all its elements into the stream.

The iterator will be consumed only from one replica, therefore this source is not parallel.

Implementations

Source

impl<It> IteratorSource<It>
where It: Iterator + Send + 'static, It::Item: Send,

pub fn new(inner: It) -> Self

Create a new source that reads the items from the iterator provided as input.

Note: this source is not parallel, the iterator will be consumed only on a single replica, on all the others no item will be read from the iterator. If you want to achieve parallelism you need to add an operator that shuffles the data (e.g. Stream::shuffle).

Example
let source = IteratorSource::new((0..5));
let s = env.stream(source);