pub enum ConnectionStrategy {
OnlyOne,
Random,
GroupBy,
All,
}Expand description
The strategy used for sending the data in a channel.
Variants
OnlyOne
The data will sent to the only replica possible. Refer to NextStrategy::OnlyOne.
Random
A random replica is chosen for sending the data.
GroupBy
A key-based approach is used for choosing the next replica.
All
All the replicas receive all the elements of the stream.