pub struct Connection {
pub to_block_id: CoordUInt,
pub data_type: DataType,
pub strategy: ConnectionStrategy,
}Expand description
A connection registered by an operator.
This tell that an operator will establish a connection with an external block. That block should have registered the corresponding receiver. The strategy can be used to customize the look of this connection.
Fields
to_block_id: CoordUIntThe id of the block that this operator is connecting to.
data_type: DataTypeThe type of data going in the channel.
strategy: ConnectionStrategyThe strategy used for sending the data in the channel.