pub struct DataType(/* private fields */);Expand description
Wrapper type that contains a string representing the type.
The internal representation should not be considered unique nor exact. Its purpose is to be nice to look at.
Implementations