pub struct OperatorReceiver {
pub previous_block_id: CoordUInt,
pub data_type: DataType,
}Expand description
A receiver registered by an operator.
This receiver tells that an operator will receive some data from the network from the specified block. Inside a block there cannot be two operators that register a receiver from the same block id.
Fields
previous_block_id: CoordUIntThe identifier of the block from which the data is arriving.
data_type: DataTypeThe type of the data coming from the channel.
Implementations
Sourceimpl OperatorReceiver
impl OperatorReceiver
Sourcepub fn new<T: ?Sized>(previous_block_id: CoordUInt) -> Self
pub fn new<T: ?Sized>(previous_block_id: CoordUInt) -> Self
Crate a new OperatorReceiver with the given type that will receive from the given block.