pub struct OperatorStructure {
pub title: String,
pub subtitle: String,
pub kind: OperatorKind,
pub receivers: Vec<OperatorReceiver>,
pub connections: Vec<Connection>,
pub out_type: DataType,
}Expand description
The structural information about an operator.
Fields
title: StringThe title of the operator.
subtitle: StringThe subtitle of the operator.
kind: OperatorKindThe kind of operator: Operator, Source or Sink.
receivers: Vec<OperatorReceiver>The list of receivers this operator registers for the block.
This does not contain the receiver from the previous operator in the block.
connections: Vec<Connection>The list of connections this operator makes.
This does not count the connection to the next operator in the block: that connection is added automatically.
out_type: DataTypeThe type of the data that comes out of this operator.
Implementations