pub struct IteratorSource<It>{ /* private fields */ }Expand description
Source that consumes an iterator and emits all its elements into the stream.
The iterator will be consumed only from one replica, therefore this source is not parallel.
Implementations
Sourceimpl<It> IteratorSource<It>
impl<It> IteratorSource<It>
Sourcepub fn new(inner: It) -> Self
pub fn new(inner: It) -> Self
Create a new source that reads the items from the iterator provided as input.
Note: this source is not parallel, the iterator will be consumed only on a single
replica, on all the others no item will be read from the iterator. If you want to achieve
parallelism you need to add an operator that shuffles the data (e.g.
Stream::shuffle).
Example
let source = IteratorSource::new((0..5));
let s = env.stream(source);Trait Implementations
Sourceimpl<It> Clone for IteratorSource<It>
impl<It> Clone for IteratorSource<It>
Sourceimpl<It> Debug for IteratorSource<It>
impl<It> Debug for IteratorSource<It>
Sourceimpl<It> Display for IteratorSource<It>
impl<It> Display for IteratorSource<It>
Sourceimpl<It> Operator for IteratorSource<It>
impl<It> Operator for IteratorSource<It>
type Out = <It as Iterator>::Item
Sourcefn setup(&mut self, _metadata: &mut ExecutionMetadata<'_>)
fn setup(&mut self, _metadata: &mut ExecutionMetadata<'_>)
Setup the operator chain. This is called before any call to
next and it’s used to
initialize the operator. When it’s called the operator has already been cloned and it will
never be cloned again. Therefore it’s safe to store replica-specific metadata inside of it. Read moreSourcefn next(&mut self) -> StreamElement<Self::Out>
fn next(&mut self) -> StreamElement<Self::Out>
Take a value from the previous operator, process it and return it.
Sourcefn structure(&self) -> BlockStructure
fn structure(&self) -> BlockStructure
A more refined representation of the operator and its predecessors.
Sourceimpl<It> Source for IteratorSource<It>
impl<It> Source for IteratorSource<It>
Sourcefn replication(&self) -> Replication
fn replication(&self) -> Replication
The maximum parallelism offered by this operator.