pub struct BlockStructure {
pub operators: Vec<OperatorStructure>,
}Expand description
The structural information about a block.
This contains the structural information about the block and the operators it contains.
Fields
operators: Vec<OperatorStructure>The structural information about the operators inside the block.
The first in the list is the start of the block, while the last is the operator that ends the block.
Implementations
Sourceimpl BlockStructure
impl BlockStructure
Sourcepub fn add_operator(self, operator: OperatorStructure) -> Self
pub fn add_operator(self, operator: OperatorStructure) -> Self
Add a new operator inside this block.